@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.50';
+  $CPAN::Perl::Releases::VERSION = '0.52';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -260,6 +260,10 @@ our $data =
     "tar.bz2" => "R/RJ/RJBS/perl-5.16.0-RC1.tar.bz2",
     "tar.gz" => "R/RJ/RJBS/perl-5.16.0-RC1.tar.gz",
   },
+  "5.16.0-RC2" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.16.0-RC2.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.16.0-RC2.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -368,7 +372,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.50
+version 0.52
 
 =head1 SYNOPSIS
 
